#!/usr/bin/env python

import os
import sys
import time
import random
import socket


from http.cookiejar import LWPCookieJar
from urllib.request import Request, urlopen
from urllib.parse import quote_plus, urlparse, parse_qs

from bs4 import BeautifulSoup

# Default use USER-AGENT , unless you change it
USER_AGENT = ('Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/73.0.3683.103 Safari/537.36')
# Default Request Headers
HEADERS = {
'Accept': 'text/html,application/xhtml+xml,application/xml',
'Accept-Encoding': 'gzip, deflate, br',
'Accept-Language': 'zh-CN,zh;q=0.9',}

# Define the default cookie file storage path
fold_dir = os.getenv('HOME')
if not fold_dir :
    fold_dir = os.getenv('USERHOME')
    if not fold_dir:
        fold_dir = '.'


# Request the given URL, PARAMS and returns the response page, using the cookie jar
def get_page(url, data=None, user_agent=None, cookie_jar=None,
             timeout=socket._GLOBAL_DEFAULT_TIMEOUT,
             **headers):
    """

    :param url:
    :param data:
    :param user_agent:
    :param cookie_jar:
    :param timeout:
    :param headers:
    :return:
    """

    if user_agent is None:
        user_agent = USER_AGENT

    request = Request(url=url, data=data)
    request.add_header('User-Agent', user_agent)
    if not headers:
        headers = HEADERS
    for k, v in headers.items():
        request.add_header(k, v)

    if cookie_jar:
        cookie_jar.add_cookie_header(request)

    response = urlopen(url=request, timeout=timeout)
    if cookie_jar:
        cookie_jar.extract_cookies(response, request)

    html = response.read()
    response.close()
    try:
        cookie_jar.save()
    except:
        pass
    return html


# Return the standard time format
def standard_timeformat(time_string):
    pass






#! -*- coding:UTF-8 -*- 
import codecs
import os
import sys
 
try:
    from setuptools import setup
except:
    from distutils.core import setup


 
def read(fname):

    return codecs.open(os.path.join(os.path.dirname(__file__), fname)).read()
 
 
 
NAME = "pysogo"

PACKAGES = ["pysogo",]

DESCRIPTION = "A simple Sogo browser with python."

 
LONG_DESCRIPTION = read("README.rst")

 
KEYWORDS = "pysogo"

AUTHOR = "chinming"

 
AUTHOR_EMAIL = "chinming95@foxmail.com"

URL = "https://github.com/cchinm/python-spider/tree/master/entertainment/pybrowser"

VERSION = "0.0.2"

 
LICENSE = "MIT"

setup(
    name = NAME,
    version = VERSION,
    description = DESCRIPTION,
    long_description = LONG_DESCRIPTION,
    classifiers = [
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
    ],
    keywords = KEYWORDS,
    author = AUTHOR,
    author_email = AUTHOR_EMAIL,
    url = URL,
    license = LICENSE,
    packages = PACKAGES,
    include_package_data=True,
    zip_safe=True,
)


#! /usr/bin/env/python

# import os
# import sys
# dir = os.path.abspath(os.path.join(os.getcwd(), os.path.pardir))
# sys.path.append(dir)
# import pybrowser


from entertainment import pybrowser


# Default sogo selector



class SogoEngine(object):

    def __init__(self):
        self.default_sogo_headers = None
        self.url_home = "https://%(tpe)s.sogou.com/%(tpe)s?query=%(query)s&type=2&ie=utf8"
        self.selectorLinks = 'div.txt-box > h3 > a'
        self.selectorTimestring = 'span.s2'

    # Return a Generator that yield URLs, using the given query string.
    def search(self, query, pause=2.0, user_agent=None, tpe='', num=10, start=0,
               end=None, tbs='', only_current_page=False, allow_domains=None, deny_domains=None,
               selector_links=None):
        """

        :param str query: Query String. Must not be URLencode
        :param float pause: A Lapse to wait between HTTP Request.
            A long Lapse can cause the search slow. A short Lapse will make the Sogo to block
            your IPs.
        :param str user_agent: Use the Default USER-AGENT for None.
        :param str tpe: Search Type (i.e web, weixin, news, videos, zhihu, pics->images ...)
        :param int num: Number of result per page
        :param int start: Offset of the first result to retrieve
        :param int/None end: Last of result to retrieve.
            Keep searching forever if None
        :param str tbs: Time limits
            (i.e d:1 last 1 day, d:2 last 2 days,
                m:1 last 1 month, y:1 last 1 year,
                '' No Time Limit)
        :param bool only_current_page: Use True to prove searching in this page /
            and Not Request next page.
        :param tuple allow_domains: Allow domains.
        :param tuple deny_domains: Deny domains.
        :return: A generator that yields URLs.
        """

        # url-encode given query string
        query = pybrowser.quote_plus(query)

        url = self.url_home % {'query':query, 'tpe':tpe}
        print(url)
        response = pybrowser.get_page(url=url,
                                      user_agent=user_agent,
                                      Cookie='SUV=00000000000000000000000000000000;')
        soup = pybrowser.BeautifulSoup(response)
        links = soup.select(selector_links)
        for link in links:
            yield link

if __name__ == '__main__':
    p =SogoEngine()
    for i in p.search(query='it may', tpe='zhihu', selector_links='div.result-about-list > h4 > a'):
        print(i)

